%--------------------------------------------------------------------------
% Represent the batch mode MFC.
% Biofilm thickness= ~ 46 micro_m
% Current Density = ~ 0.2 mA/cm2
%--------------------------------------------------------------------------
function sol=case3_original_2_scaled_death_working_with_res

clear all
clc

k_sd=1E-5*100;
x_0=[2.2*10^-5/k_sd,0,0.3,0,0.00048*10^4,0.8,0.189,0,0]; % works for varLf
Lf=4;

%solinit = bvpinit(linspace(0,1,6),x_0,Lf);

load NEW_TEST_3_6;
solinit = bvpinit(sol, [0 1],sol.parameters);
options=bvpset('RelTol',1e-6,'NMax',4000);
sol = bvp4c(@odefun,@bcfun,solinit,options);            % solves system of ODEs

 x = linspace(0,1,10);
 y = deval(sol,x);
%save NEW_TEST_3_6 sol x y solinit;
 
% --------------------------------- ODE solutoin plots--------------------- 
%  figure
%  plot(x,y(6,:),x,1-y(6,:)-y(9,:),x,y(9,:));
%  title('Active and Inactive biomass')
%  legend('act','inac','res');
%  xlabel('Distance z (m)')
%  ylabel('Biomass fraction')
%  
%  figure
%  plot(x,y(1,:)*k_sd);
%  title('Substrate Concentration')
%  xlabel('Distance z (m)')
%  ylabel('Substrate Concentration (mmol/cm3)')
% 
%  figure
%  plot(x,y(3,:));
%  title('Local Potential')
%  xlabel('Distance z (m)')
%  ylabel('Local Potential (V)')
% 
%  figure
%  plot(x,y(5,:)/10^4);
%  title('Advection Velocity')
%  xlabel('Distance z (m)')
%  ylabel('Advection Velocity (cm/days)')
% 
%  figure
%  plot(x,y(7,:));
%  title('Current density')
%  xlabel('Distance z (m)')
%  ylabel('Current density (mA/cm2)')
%  
%  figure
%  plot(x,y(8,:));
%  title('death rate rd')
%  xlabel('Distance z (m)')
%  ylabel('rd(cm/day)')
%  
%   figure
%  plot(sol.x,sol.yp(5,:)./sol.y(6,:),sol.x,sol.yp(8,:));
%  title('Comparison of cell death and growth')
%  xlabel('Distance z (m)')
%  ylabel('Substrate Concentration (1/day)')

%-------------------------------------------------------------------------
%   System of ODEs describing the processes of biofilm
%-------------------------------------------------------------------------
function dydx = odefun(x,y,Lf)

yp=y([2,7]); % Current 7old
yp(yp<0)=0;
y([2,7])=yp;

% yq=y([6]); % active bio old
% yq(yq<0)=0.1;
% y([6])=yq;

ys=y([5,8]); % v and vd old
ys(ys<0)=0.001;
y([5,8])=ys;

% yt=y([7]); % vd old
% yt(yt>0.1848)=0.1848;
% y([7])=yt;

% yt=y([3]); % vd
% yt(yt>0.3)=0.3;
% y([3])=yt;

     x_fa= 938;
     d_ed_f=0.188;
     k_sd=100*1E-5;
     F=96485;
     time_conv=86400;
     k_bio=0.525;% DL1 conductivity (0.05,0.005,0.001,0.0005,0.0002)    
     q_max=0.131; % units = mmol ED/mg VS.day
     
   
     
load AC_FLUX_newBulk.txt;
load CELL_GROWTH_newBulk.txt;
load E_FLUX_newBulk.txt;


%--------------------------lookup table------------------------------------
for k=1:length(y(3,:))
    if (y(3)>=-0.34 && y(1)*k_sd>=2.33E-6)
        
        
        x_FBA (1)= intepol1(AC_FLUX_newBulk,y(1)*k_sd,y(3));     % Acetate flux
        x_FBA (2)= intepol1(E_FLUX_newBulk,y(1)*k_sd,y(3));      % electron flux
        x_FBA (3)= intepol1(CELL_GROWTH_newBulk,y(1)*k_sd,y(3)); % cell growth rate
        cell_death=0;
        q_Ac_min=8.*q_max.*(0.00233./(0.00233+0.01)); % min Ac. consumption to maintain ATPm
    else
        x_FBA = zeros(3,length(y(3,:)));
        cell_death=0.1018;
        q_Ac_min= 0;
       
    end
end
y
x

Lf=Lf/1000

x_FBA
if sum(isnan(y))>=1
    error('help');
end

%-----------------converting FBA units to biofilim model units-------------
q= -1*x_FBA(1)*((24*100)/(90*1000)).*y(6);  % Acetate rate
e_rate=x_FBA(2)*((24*100)/(90*1000)).*y(6)  % electron rate due to active biomass
cell_growth = x_FBA(3)*24*y(6);             % cell growth rate
e_res=y(9).*q_Ac_min % electron rate due to respiring biomass

r_ina=0.03*y(6);    % inactivation rate
r_conv=0.09*y(6);   % coversion rate to respiring biomass

     dydx= [y(2)                                                                % dSd/dz
           (x_fa*((q+(e_res/8))/k_sd)*(Lf)^2)/d_ed_f                            % d2Sd/dz2
            y(4)                                                                % dn/dz
           (((F*x_fa*e_rate)+(F*x_fa*e_res))*Lf^2)/(time_conv*k_bio)            % d2n/dz2
           (cell_growth)*Lf*10^4                                                % dv/dz 
           ((((1-y(6))*cell_growth)-r_conv-r_ina)*Lf)/(y(5)/10^4)               % dactive_bio/dz
           (((-F*x_fa*e_rate)+(-F*x_fa*e_res))*Lf)/(time_conv)                  % dj/dz
           (cell_death)*Lf*10^4                                                      % dvd/dz
           ((r_conv-((y(9)*cell_growth)))*Lf)/(y(5)/10^4)                       % dresp_bio/dz
           ];
       
%-------------------------------------------------------------------------
%   Boundary conditions for the ODEs   
%----------------------------------------------------------------------        
function res = bcfun(ya,yb,Lf)
       
        d_ed_f=0.188;
        d_ed_l=0.941;
        s_d_bulk=1E-2/(100*1E-5);
        L=0.45;
        Lf=Lf/1000;
        
        r_lysis=0.0504;
        b_det=0;
        
        res=[ya(2)                                     % dSd/dz at z=0
            yb(2)-((d_ed_l*(s_d_bulk-yb(1))*Lf)/(d_ed_f*L)) % dSd/dz at z=Lf
            ya(3)- 0.3                                  % n at z=0
            yb(4)                                       % dn/dz at z=Lf
            ya(5)- 5.2                                  % v at z=0
            yb(5)- (r_lysis*Lf*10^4)-(b_det*Lf*10^4) - yb(8)  % v at z=Lf                 
            ya(6)- 0.1                                  % active_bio z=0                               
            yb(7)                                       % j at z=Lf
            ya(8)- 0                                    % rd at z=0
            ya(9)- 0.4                                  % resp_bio z=0

            ];