function [Ac_flux,cell_growth,e_flux,proton_flux,H2_rate,N2_rate]= lookup_table 

% DL1 
n = linspace(-0.34,0.5,20);
Sd = linspace(2.33E-6,1E-2,20);

q_max=4.9875; % units = mmol ED/g dw.hr
k_sd=1E-5;    % half max. rate

F=96500;
T=298.15; 
R=8.314;
E_0=-0.345;

% Calculating the uptake rates based on ED conc. and local potential
for i=1:length(n)
    q_Ac(i)=q_max.*(Sd(i)./(Sd(i)+k_sd));
    q_e(i)=8.*q_max.*(1./(1+exp(-F*(n(i)-E_0)./(R*T))));
end

% Generating lookup table
for  i=1:length(n)
    Ac_uptake=q_Ac(i);
    

    for j=1:length(n)
        e_rate=q_e(j);
        Sd(i)
        n(j)
        FBA_sol= test(Ac_uptake,e_rate);
              
        Ac_flux(i,j)=FBA_sol(47); % Acetate flux
        cell_growth (i,j)= FBA_sol(45); % cell growth rate
        e_flux(i,j)=FBA_sol(55); % electron flux
        proton_flux(i,j)=FBA_sol(61); % proton flux
        H2_rate (i,j)=FBA_sol(62); % hydrogen flux
        N2_rate(i,j)=FBA_sol(74); % nitrogen flux
        CO2_rate(i,j)=FBA_sol(52); % co2 flux
        H2O_rate(i,j)=FBA_sol(63); % water flux
        NH4_rate(i,j)=FBA_sol(76); % ammonium 
    end

end

myFormat='%12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f %12.8f\n';
% open a file for writing
fid1 = fopen('AC_FLUX_newBulk.txt', 'w');
fid2 = fopen('CELL_GROWTH_newBulk.txt', 'w');
fid3 = fopen('E_FLUX_newBulk.txt', 'w');
fid4 = fopen('PROTON_FLUX_newBulk.txt', 'w');
% fid5 = fopen('H2_FLUX_newBulk.txt', 'w');
% fid6 = fopen('N2_FLUX_newBulk.txt', 'w');
% fid7 = fopen('CO2_FLUX_newBulk.txt', 'w');
% fid8 = fopen('H2O_FLUX_newBulk.txt', 'w');
% fid9 = fopen('NH4_FLUX_newBulk.txt', 'w');

% print values in column order
% two values appear on each row of the file
for i=1:20
fprintf(fid1, myFormat, Ac_flux(i,:));
fprintf(fid2, myFormat, cell_growth(i,:));
fprintf(fid3, myFormat, e_flux(i,:));
fprintf(fid4, myFormat, proton_flux(i,:));
% fprintf(fid5, myFormat, H2_rate(i,:));
% fprintf(fid6, myFormat, N2_rate(i,:));
% fprintf(fid7, myFormat, CO2_rate(i,:));
% fprintf(fid8, myFormat, H2O_rate(i,:));
% fprintf(fid9, myFormat, NH4_rate(i,:));
end

fclose(fid1);
fclose(fid2);
fclose(fid3);
fclose(fid4);
% fclose(fid5);
% fclose(fid6);
% fclose(fid7);
% fclose(fid8);
% fclose(fid9);
